Index: src/client/windows/handler/exception_handler.h |
=================================================================== |
--- src/client/windows/handler/exception_handler.h (revision 972) |
+++ src/client/windows/handler/exception_handler.h (working copy) |
@@ -153,7 +153,7 @@ |
void* callback_context, |
int handler_types); |
// Creates a new ExcetpionHandler instance that can attempt to perform |
// out-of-process dump generation if pipe_name is not NULL. If pipe_name is |
// NULL, or if out-of-process dump generation registration step fails, |
// in-process dump generation will be used. This also allows specifying |
@@ -167,6 +167,17 @@ |
const wchar_t* pipe_name, |
const CustomClientInfo* custom_info); |
+ // As above, creates a new ExceptionHandler instance to perform |
+ // out-of-process dump generation if the given pipe_handle is not NULL. |
+ ExceptionHandler(const wstring& dump_path, |
+ FilterCallback filter, |
+ MinidumpCallback callback, |
+ void* callback_context, |
+ int handler_types, |
+ MINIDUMP_TYPE dump_type, |
+ HANDLE pipe_handle, |
+ const CustomClientInfo* custom_info); |
+ |
~ExceptionHandler(); |
// Get and set the minidump path. |
@@ -219,6 +230,7 @@ |
int handler_types, |
MINIDUMP_TYPE dump_type, |
const wchar_t* pipe_name, |
+ HANDLE pipe_handle, |
const CustomClientInfo* custom_info); |
// Function pointer type for MiniDumpWriteDump, which is looked up |
@@ -153,7 +153,7 @@ |
void* callback_context, |
int handler_types); |
- // Creates a new ExcetpionHandler instance that can attempt to perform |
+ // Creates a new ExceptionHandler instance that can attempt to perform |
// out-of-process dump generation if pipe_name is not NULL. If pipe_name is |
// NULL, or if out-of-process dump generation registration step fails, |